# Perfil

[![license MIT][0]][1] [![python version][2]][3] [![pypi package][4]][5]
[![style black][6]][7] [![lint: flake8][8]][9] [![test: pytest][10]][11]

Profile python functions.

---

[0]: https://img.shields.io/github/license/jcpedroza/perfil?color=%2310af6f
[1]: https://en.wikipedia.org/wiki/MIT_License
[2]: https://img.shields.io/pypi/pyversions/perfil
[3]: https://img.shields.io/pypi/pyversions/perfil
[4]: https://img.shields.io/pypi/v/perfil
[5]: https://pypi.org/project/perfil/
[6]: https://img.shields.io/badge/code%20style-black-000000.svg
[7]: https://github.com/psf/black
[8]: https://img.shields.io/badge/lint-flake8-blue.svg
[9]: https://github.com/PyCQA/flake8
[10]: https://img.shields.io/badge/test-pytest-blue.svg
[11]: https://github.com/pytest-dev/pytest
